@@ -2,8 +2,6 @@
 """ API for AWS Content Management """
 
 
-import os
-
 from baseblock import EnvIO
 from baseblock import BaseObject
 
@@ -82,7 +80,7 @@ class AwsAPI(BaseObject):
 
         Args:
             bucket_name (str): the name of the bucket
-                e.g., iceberg-data-core
+                e.g., name-of-bucket
             file_name (str): the qualified name of the file
                 e.g., 'training/myeliza/doctor'
 
@@ -103,7 +101,7 @@ class AwsAPI(BaseObject):
 
         Args:
             bucket_name (str): the name of the bucket
-                e.g., iceberg-data-core
+                e.g., name-of-bucket
             file_name (str): the qualified name of the file
                 e.g., 'training/myeliza/doctor'
             file_ext (str): the file extension
@@ -132,40 +130,3 @@ class AwsAPI(BaseObject):
             file_name=file_name,
             file_ext=file_ext,
             version=version)
-
-    # def ontology_by_version(self,
-    #                         bucket_name: str,
-    #                         model_name: str,
-    #                         version: str) -> dict:
-    #     """ Access a Versioned Ontology File
-
-    #     Args:
-    #         bucket_name (str): the name of the bucket
-    #             e.g., iceberg-data-core
-    #         file_name (str): the non-qualified name of the ontology model
-    #             e.g., 'ontologica'
-    #         version (str): the version of the file to access
-    #             e.g., '0.1.0'
-
-    #     Returns:
-    #         str: the absolute path containing both files
-    #     """
-
-    #     file_name = f"owl/{model_name}"
-
-    #     owl_path = self.file_by_version(
-    #         bucket_name=bucket_name,
-    #         file_name=file_name,
-    #         file_ext='owl',
-    #         version=version)
-
-    #     self.file_by_version(
-    #         bucket_name=bucket_name,
-    #         file_name=file_name,
-    #         file_ext='txt',
-    #         version=version)
-
-    #     basename = os.path.basename(owl_path)
-    #     base_path = owl_path.split(basename)[0].strip()
-
-    #     return base_path
