@@ -3,6 +3,7 @@
 
 
 from baseblock import EnvIO
+from baseblock import Enforcer
 from baseblock import CryptoBase
 from baseblock import BaseObject
 
@@ -22,9 +23,11 @@ class CredentialManager(BaseObject):
 
         self._access_key = EnvIO.as_str(
             'AWS_ACCESS_KEY', 'AWS_ACCESS_KEY_LOCAL')
+        Enforcer.is_str(self._access_key)
 
         self._secret_key = EnvIO.as_str(
             'AWS_SECRET_KEY', 'AWS_SECRET_KEY_LOCAL')
+        Enforcer.is_str(self._secret_key)
 
     def access_key(self) -> str:
         return CryptoBase().decrypt_str(self._access_key)
